scipy.sparse.sputils
====================

.. automodule:: scipy.sparse.sputils

   
   
   .. rubric:: Functions

   .. autosummary::
   
      getdtype
      isdense
      isintlike
      isscalarlike
      issequence
      isshape
      to_native
      upcast
   
   

   
   
   

   
   
   